# Documentation for `BaseModelWrapper`
::: photonai.modelwrapper.base_model_wrapper.BaseModelWrapper
    selection:
      members:
        - __init__
        - transform
        - predict
        - fit
        - set_params
        - get_params
